Collection

Struct Collection 

pub struct Collection {
    pub id: Option<Uuid>,
    pub organization_id: Option<Uuid>,
    pub name: Option<String>,
    pub external_id: Option<String>,
    pub creation_date: Option<String>,
    pub revision_date: Option<String>,
    pub type: Option<CollectionType>,
    pub default_user_collection_email: Option<String>,
    pub access_rule_id: Option<Uuid>,
}
Collection : A named grouping of vault items within an organization, used to share items with members and groups. Access is granted to individual members via Bit.Core.Entities.CollectionUser and to groups via Bit.Core.Entities.CollectionGroup.

Fields

id: Option<Uuid>

A unique identifier for the collection.

organization_id: Option<Uuid>

The ID of the Bit.Core.AdminConsole.Entities.Organization that owns this collection.

name: Option<String>

The name of the collection, stored encrypted.

external_id: Option<String>

An ID used to associate this collection with a record in external services.

creation_date: Option<String>

The date the collection was created.

revision_date: Option<String>

The date the collection was last updated.

type: Option<CollectionType>default_user_collection_email: Option<String>

Used as the name for the collection if this is a Bit.Core.Enums.CollectionType.DefaultUserCollection of a user who is no longer a member of the organization. In this case, it stores the user’s email address so that it is identifiable by an admin (rather than being called "My Items" for an unknown user). Unencrypted.

access_rule_id: Option<Uuid>

Reference to the AccessRule that gates PAM credential leasing for this collection. Null means leasing is disabled for the collection.

Implementations

Source

impl Collection

pub fn new() -> Collection

A named grouping of vault items within an organization, used to share items with members and groups. Access is granted to individual members via Bit.Core.Entities.CollectionUser and to groups via Bit.Core.Entities.CollectionGroup.